@@ -19,6 +19,7 @@
 
 #include <iostream>
 
+#include <Lum/Base/L10N.h>
 #include <Lum/Base/String.h>
 
 #include <Lum/Button.h>
@@ -33,7 +34,6 @@
 #include <Lum/Text.h>
 #include <Lum/TextValue.h>
 #include <Lum/View.h>
-#include <Lum/WindowGroup.h>
 
 #include <Lum/Dlg/About.h>
 #include <Lum/Dlg/Msg.h>
@@ -67,8 +67,8 @@ public:
   {
     okAction->Disable();
 
-    AttachModel(okAction);
-    AttachModel(selection);
+    Observe(okAction);
+    Observe(selection);
 
     for (size_t i=0; i<Collection::GetCollectionCount(); ++i) {
       Lum::Model::ListTable::StdEntry *entry;
@@ -88,28 +88,18 @@ public:
     }
   }
 
-  ~SelectCollection()
-  {
-    UnattachModel(selection);
-    UnattachModel(okAction);
-  }
-
   void PreInit()
   {
-    Lum::Button           *button;
     Lum::ButtonRow        *bRow;
     Lum::Panel            *panel;
     Lum::Table            *table;
-    Lum::WindowGroup      *wGroup;
     Lum::Model::HeaderRef headerModel;
 
-    wGroup=new Lum::WindowGroup();
-    wGroup->SetFlex(true,true);
-    wGroup->SetWidth(Lum::Base::Size::modePixel,(GetWindow()->GetParent()->GetWidth()*80)/100);
-    wGroup->SetHeight(Lum::Base::Size::modePixel,(GetWindow()->GetParent()->GetHeight()*80)/100);
 
     panel=new Lum::VPanel();
     panel->SetFlex(true,true);
+    panel->SetWidth(Lum::Base::Size::pixel,(GetWindow()->GetParent()->GetWidth()*80)/100);
+    panel->SetHeight(Lum::Base::Size::pixel,(GetWindow()->GetParent()->GetHeight()*80)/100);
 
     headerModel=new Lum::Model::HeaderImpl();
     headerModel->AddColumn(L"Collection",Lum::Base::Size::stdCharWidth,25);
@@ -126,27 +116,11 @@ public:
 
     panel->Add(new Lum::VSpace());
 
-    bRow=new Lum::ButtonRow();
+    bRow=Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction());
     bRow->SetFlex(true,false);
     panel->Add(bRow);
 
-    button=new Lum::Button();
-    button->SetFlex(true,true);
-    button->SetModel(okAction);
-    button->SetType(Lum::Button::typeCommit);
-    button->SetText(L"_Ok");
-    bRow->Add(button);
-
-    button=new Lum::Button();
-    button->SetFlex(true,true);
-    button->SetModel(GetClosedAction());
-    button->SetType(Lum::Button::typeCancel);
-    button->SetText(L"_Cancel");
-    bRow->Add(button);
-
-    wGroup->SetMain(panel);
-
-    SetTop(wGroup);
+    SetMain(panel);
 
     Dialog::PreInit();
   }
@@ -199,35 +173,24 @@ public:
   {
     okAction->Disable();
 
-    AttachModel(okAction);
-    AttachModel(selection);
+    Observe(okAction);
+    Observe(selection);
 
     for (size_t i=0; i<collection->GetLevelCount() && i<=collection->GetCurrent(); ++i) {
       list->AppendString(collection->GetLevel(i).GetTitle());
     }
   }
 
-  ~SelectLevel()
-  {
-    UnattachModel(selection);
-    UnattachModel(okAction);
-  }
-
   void PreInit()
   {
-    Lum::Button      *button;
     Lum::ButtonRow   *bRow;
     Lum::Panel       *panel;
     Lum::Table       *table;
-    Lum::WindowGroup *wGroup;
-
-    wGroup=new Lum::WindowGroup();
-    wGroup->SetFlex(true,true);
-    wGroup->SetWidth(Lum::Base::Size::modePixel,(GetWindow()->GetParent()->GetWidth()*80)/100);
-    wGroup->SetHeight(Lum::Base::Size::modePixel,(GetWindow()->GetParent()->GetHeight()*80)/100);
 
     panel=new Lum::VPanel();
     panel->SetFlex(true,true);
+    panel->SetWidth(Lum::Base::Size::pixel,(GetWindow()->GetParent()->GetWidth()*80)/100);
+    panel->SetHeight(Lum::Base::Size::pixel,(GetWindow()->GetParent()->GetHeight()*80)/100);
 
     table=new Lum::Table();
     table->SetFlex(true,true);
@@ -238,27 +201,11 @@ public:
 
     panel->Add(new Lum::VSpace());
 
-    bRow=new Lum::ButtonRow();
+    bRow=Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction());
     bRow->SetFlex(true,false);
     panel->Add(bRow);
 
-    button=new Lum::Button();
-    button->SetFlex(true,true);
-    button->SetModel(okAction);
-    button->SetType(Lum::Button::typeCommit);
-    button->SetText(L"_Ok");
-    bRow->Add(button);
-
-    button=new Lum::Button();
-    button->SetFlex(true,true);
-    button->SetModel(GetClosedAction());
-    button->SetType(Lum::Button::typeCancel);
-    button->SetText(L"_Cancel");
-    bRow->Add(button);
-
-    wGroup->SetMain(panel);
-
-    SetTop(wGroup);
+    SetMain(panel);
 
     Dialog::PreInit();
   }
@@ -313,8 +260,8 @@ public:
   {
     okAction->Disable();
 
-    AttachModel(okAction);
-    AttachModel(selection);
+    Observe(okAction);
+    Observe(selection);
 
 
     for (size_t i=0; i<themes.size(); ++i) {
@@ -328,28 +275,17 @@ public:
     }
   }
 
-  ~SelectTheme()
-  {
-    UnattachModel(selection);
-    UnattachModel(okAction);
-  }
-
   void PreInit()
   {
-    Lum::Button           *button;
     Lum::ButtonRow        *bRow;
     Lum::Panel            *panel;
     Lum::Table            *table;
-    Lum::WindowGroup      *wGroup;
     Lum::Model::HeaderRef headerModel;
 
-    wGroup=new Lum::WindowGroup();
-    wGroup->SetFlex(true,true);
-    wGroup->SetWidth(Lum::Base::Size::modePixel,(GetWindow()->GetParent()->GetWidth()*80)/100);
-    wGroup->SetHeight(Lum::Base::Size::modePixel,(GetWindow()->GetParent()->GetHeight()*80)/100);
-
     panel=new Lum::VPanel();
     panel->SetFlex(true,true);
+    panel->SetWidth(Lum::Base::Size::pixel,(GetWindow()->GetParent()->GetWidth()*80)/100);
+    panel->SetHeight(Lum::Base::Size::pixel,(GetWindow()->GetParent()->GetHeight()*80)/100);
 
     headerModel=new Lum::Model::HeaderImpl();
     headerModel->AddColumn(L"Theme name",Lum::Base::Size::stdCharWidth,25);
@@ -366,27 +302,11 @@ public:
 
     panel->Add(new Lum::VSpace());
 
-    bRow=new Lum::ButtonRow();
+    bRow=Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction());
     bRow->SetFlex(true,false);
     panel->Add(bRow);
 
-    button=new Lum::Button();
-    button->SetFlex(true,true);
-    button->SetModel(okAction);
-    button->SetType(Lum::Button::typeCommit);
-    button->SetText(L"_Ok");
-    bRow->Add(button);
-
-    button=new Lum::Button();
-    button->SetFlex(true,true);
-    button->SetModel(GetClosedAction());
-    button->SetType(Lum::Button::typeCancel);
-    button->SetText(L"_Cancel");
-    bRow->Add(button);
-
-    wGroup->SetMain(panel);
-
-    SetTop(wGroup);
+    SetMain(panel);
 
     Dialog::PreInit();
   }
@@ -450,47 +370,29 @@ public:
     pushes(new Lum::Model::String()),
     gameArea(new GameArea)
   {
-    AttachModel(categoryAction);
-    AttachModel(levelAction);
-    AttachModel(themeAction);
-    AttachModel(restartAction);
-    AttachModel(undoAction);
-    AttachModel(aboutAction);
+    Observe(categoryAction);
+    Observe(levelAction);
+    Observe(themeAction);
+    Observe(restartAction);
+    Observe(undoAction);
+    Observe(aboutAction);
 
-    AttachModel(gameArea->GetFinishedModel());
+    Observe(gameArea->GetFinishedModel());
 
     moves->Set(L"0");
     pushes->Set(L"0");
   }
 
-  ~MainDialog()
-  {
-    UnattachModel(gameArea->GetFinishedModel());
-
-    UnattachModel(aboutAction);
-    UnattachModel(undoAction);
-    UnattachModel(restartAction);
-    UnattachModel(themeAction);
-    UnattachModel(levelAction);
-    UnattachModel(categoryAction);
-  }
-
   void PreInit()
   {
     Lum::Button      *button;
     Lum::Label       *label;
     Lum::LED         *led;
-    Lum::Menu        *menu;
-    Lum::MenuStrip   *menuStrip;
     Lum::Panel       *horiz;
     Lum::Panel       *horiz2;
     Lum::Panel       *vert;
     Lum::TextValue   *textValue;
     Lum::View        *view;
-    Lum::WindowGroup *wGroup;
-
-    wGroup=new Lum::WindowGroup();
-    wGroup->SetFlex(true,true);
 
     horiz=new Lum::HPanel();
     horiz->SetFlex(true,true);
@@ -514,7 +416,7 @@ public:
     vert->SetFlex(false,true);
 
     label=new Lum::Label;
-
+    /*
     horiz2=new Lum::HPanel();
     horiz2->SetFlex(true,false);
 
@@ -529,14 +431,14 @@ public:
     button->SetText(L"...");
     horiz2->Add(button);
 
-    label->AddLabel(L"Collection:",horiz2);
+    label->AddLabel(L"Collection:",horiz2);*/
 
     horiz2=new Lum::HPanel();
     horiz2->SetFlex(true,false);
 
     textValue=new Lum::TextValue();
     textValue->SetFlex(true,false);
-    textValue->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
+    textValue->SetMinWidth(Lum::Base::Size::stdCharWidth,5);
     textValue->SetModel(levelName);
     horiz2->Add(textValue);
 
@@ -547,22 +449,6 @@ public:
 
     label->AddLabel(L"Level:",horiz2);
 
-    horiz2=new Lum::HPanel();
-    horiz2->SetFlex(true,false);
-
-    textValue=new Lum::TextValue();
-    textValue->SetFlex(true,false);
-    textValue->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
-    textValue->SetModel(themeName);
-    horiz2->Add(textValue);
-
-    button=new Lum::Button();
-    button->SetModel(themeAction);
-    button->SetText(L"...");
-    horiz2->Add(button);
-
-    label->AddLabel(L"Theme:",horiz2);
-
     textValue=new Lum::TextValue();
     textValue->SetFlex(true,false);
     textValue->SetMinWidth(Lum::Base::Size::stdCharWidth,5);
@@ -599,30 +485,27 @@ public:
 
     horiz->Add(vert);
 
-    wGroup->SetMain(horiz);
+    SetMain(horiz);
 
-    menuStrip=new Lum::MenuStrip();
+    Lum::MenuDesc *menu=new Lum::MenuDesc();
 
-    menu=new Lum::Menu();
-    menu->AddActionItem(L"_Quit",GetClosedAction(),Lum::OS::qualifierControl,L"q");
-    menuStrip->AddPullDownMenu(L"_Project",menu);
+    menu
+      ->AddMenuItemSub(_ld(menuProject))
+        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
+    menu
+      ->AddMenuItemSub(L"_Game")
+        ->AddMenuItemAction(L"_Choose category",Lum::OS::qualifierControl,L"c",categoryAction)
+        ->AddMenuItemAction(L"Choose _level",Lum::OS::qualifierControl,L"l",levelAction)
+        ->AddMenuItemAction(L"Choose _theme",Lum::OS::qualifierControl,L"t",themeAction)
+        ->AddSeparator()
+        ->AddMenuItemAction(L"_Restart level",Lum::OS::qualifierControl,L"r",restartAction)
+        ->AddMenuItemAction(L"_Undo step",Lum::OS::qualifierControl,L"u",restartAction);
+    menu
+      ->AddMenuItemSub(_ld(menuHelp))
+        ->AddMenuItemAction(_ld(menuHelpHelp),NULL)
+        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
 
-    menu=new Lum::Menu();
-    menu->AddActionItem(L"_Choose _category",categoryAction,Lum::OS::qualifierControl,L"c");
-    menu->AddActionItem(L"Choose _level",levelAction,Lum::OS::qualifierControl,L"l");
-    menu->AddActionItem(L"Choose _theme",themeAction,Lum::OS::qualifierControl,L"t");
-    menu->AddSeparator();
-    menu->AddActionItem(L"_Restart level",restartAction,Lum::OS::qualifierControl,L"r");
-    menu->AddActionItem(L"_Undo step",restartAction,Lum::OS::qualifierControl,L"u");
-    menuStrip->AddPullDownMenu(L"_Game",menu);
-
-    menu=new Lum::Menu();
-    menu->AddActionItem(L"_About",aboutAction);
-    menuStrip->AddPullDownMenu(L"_Help",menu);
-
-    wGroup->SetMenuStrip(menuStrip);
-
-    SetTop(wGroup);
+    SetMenu(menu);
 
     Dialog::PreInit();
   }
